DEFAULT_SHEET_TASKS = "tasks"
DEFAULT_SHEET_META = "data"

COL_META_DATE_OFFSET = "start date"
COL_META_VERSION_MAJOR = "version_major"
COL_META_VERSION_MINOR = "version_minor"
COL_META_VERSION_PATCH = "version_patch"
COL_META_HORIZON_GRANULARITY = "horizon_granularity"

COLNUM_META_DATE_OFFSET = 1
COLNUM_META_VERSION_MAJOR = 2
COLNUM_META_VERSION_MINOR = 3
COLNUM_META_VERSION_PATCH = 4

ROWNUM_META_INFO = 2

COL_TASK_ID = "Task ID"
COL_TASK_NAME = "Task Name"
COL_TASK_EFFORT = "Effort"
COL_TASK_ES = "ES"
COL_TASK_LF = "LF"
COL_TASK_START = "Task Start"
COL_TASK_FINISH = "Task Finish"
COL_TASK_WEEK_PREFIX = "Week Prefix"
COL_TASK_PROGRESS = "Progress"
COL_TASK_COSTS = "Costs"

COL_HORIZON_START = "Horizon Start"
COL_HORIZON_END = "Horizon End"

EXCEL_COL_NAMES_V0 = {
    COL_TASK_ID: "Task ID",
    COL_TASK_NAME: "Task Name",
    COL_TASK_ES: "ES",
    COL_TASK_LF: "LF",
    COL_TASK_START: "Task Start",
    COL_TASK_FINISH: "Task Finish",
    COL_TASK_WEEK_PREFIX: "Week ",
    COL_TASK_PROGRESS: "Progress",
    COL_TASK_EFFORT: "Effort (weeks)",
    COL_HORIZON_START: "Horizon Start",
    COL_HORIZON_END: "Horizon End",
}

EXCEL_COL_NAMES = {
    COL_TASK_ID: "Task ID",
    COL_TASK_NAME: "Task Name",
    COL_TASK_ES: "ES",
    COL_TASK_LF: "LF",
    COL_TASK_START: "Task Start",
    COL_TASK_FINISH: "Task Finish",
    COL_TASK_WEEK_PREFIX: "Week ",
    COL_TASK_PROGRESS: "Progress",
    COL_TASK_EFFORT: "Effort",
    COL_HORIZON_START: "Horizon Start",
    COL_HORIZON_END: "Horizon End",
    COL_TASK_COSTS: "Costs"
}